==> com.liferay.gradle.plugins.defaults-7.0.193-sources-commercial.jar: com/liferay/gradle/plugins/defaults/PoshiRunnerResourcesDefaultsPlugin.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.gradle.plugins.defaults;

import com.liferay.gradle.plugins.defaults.internal.util.GitRepo;
import com.liferay.gradle.plugins.defaults.internal.util.GradleUtil;
import com.liferay.gradle.plugins.poshi.runner.PoshiRunnerResourcesExtension;
import com.liferay.gradle.plugins.poshi.runner.PoshiRunnerResourcesPlugin;

import groovy.lang.Closure;

import java.io.File;

import org.gradle.api.Action;
import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.Task;
import org.gradle.api.artifacts.Configuration;
import org.gradle.api.artifacts.PublishArtifactSet;
import org.gradle.api.artifacts.dsl.RepositoryHandler;
import org.gradle.api.artifacts.maven.MavenDeployer;
import org.gradle.api.artifacts.maven.MavenPom;
import org.gradle.api.internal.artifacts.publish.ArchivePublishArtifact;
import org.gradle.api.plugins.MavenPlugin;
import org.gradle.api.plugins.MavenRepositoryHandlerConvention;
import org.gradle.api.specs.Spec;
import org.gradle.api.tasks.Upload;
import org.gradle.api.tasks.bundling.AbstractArchiveTask;

/**
 * @author Andrea Di Giorgi
 */
public class PoshiRunnerResourcesDefaultsPlugin implements Plugin<Project> {

	public static final String ARTIFACT_APPENDIX_PROPERTY_NAME =
		"artifactAppendix";

	public static final String ARTIFACT_VERSION_PROPERTY_NAME =
		"artifactVersion";

	@Override
	public void apply(Project project) {
		GradleUtil.applyPlugin(project, MavenPlugin.class);
		GradleUtil.applyPlugin(project, PoshiRunnerResourcesPlugin.class);

		_applyConfigScripts(project);
		_configurePoshiRunnerResources(project);
		_configureTaskUploadPoshiRunnerResources(project);
	}

	private void _applyConfigScripts(Project project) {
		GradleUtil.applyScript(
			project,
			"com/liferay/gradle/plugins/defaults/dependencies" +
				"/config-maven.gradle",
			project);
	}

	private void _configurePoshiRunnerResources(Project project) {
		PoshiRunnerResourcesExtension poshiRunnerResourcesExtension =
			GradleUtil.getExtension(
				project, PoshiRunnerResourcesExtension.class);

		poshiRunnerResourcesExtension.setRootDirName(_ROOT_DIR_NAME);

		if (project.hasProperty(ARTIFACT_APPENDIX_PROPERTY_NAME)) {
			String artifactAppendix = GradleUtil.getProperty(
				project, ARTIFACT_APPENDIX_PROPERTY_NAME, (String)null);

			poshiRunnerResourcesExtension.setArtifactAppendix(artifactAppendix);
		}

		if (project.hasProperty(ARTIFACT_VERSION_PROPERTY_NAME)) {
			String artifactVersion = GradleUtil.getProperty(
				project, ARTIFACT_VERSION_PROPERTY_NAME, (String)null);

			poshiRunnerResourcesExtension.setArtifactVersion(artifactVersion);
		}
	}

	private void _configureTaskUploadPoshiRunnerResources(
		final Project project) {

		Upload upload = (Upload)GradleUtil.getTask(
			project,
			PoshiRunnerResourcesPlugin.UPLOAD_POSHI_RUNNER_RESOURCES_TASK_NAME);

		upload.onlyIf(
			new Spec<Task>() {

				@Override
				public boolean isSatisfiedBy(Task task) {
					GitRepo gitRepo = GitRepo.getGitRepo(
						project.getProjectDir());

					if ((gitRepo != null) && gitRepo.readOnly) {
						return false;
					}

					return true;
				}

			});

		RepositoryHandler repositoryHandler = upload.getRepositories();

		final MavenDeployer mavenDeployer =
			(MavenDeployer)repositoryHandler.getAt(
				MavenRepositoryHandlerConvention.DEFAULT_MAVEN_DEPLOYER_NAME);

		Configuration configuration = upload.getConfiguration();

		PublishArtifactSet publishArtifactSet = configuration.getAllArtifacts();

		publishArtifactSet.withType(
			ArchivePublishArtifact.class,
			new Action<ArchivePublishArtifact>() {

				@Override
				@SuppressWarnings("serial")
				public void execute(
					ArchivePublishArtifact archivePublishArtifact) {

					AbstractArchiveTask abstractArchiveTask =
						archivePublishArtifact.getArchiveTask();

					final String name = abstractArchiveTask.getArchiveName();

					mavenDeployer.addFilter(
						name,
						new Closure<Boolean>(project) {

							@SuppressWarnings("unused")
							public Boolean doCall(Object artifact, File file) {
								if (name.equals(file.getName())) {
									return true;
								}

								return false;
							}

						});

					MavenPom mavenPom = mavenDeployer.pom(name);

					mavenPom.setGroupId(_GROUP_ID);
					mavenPom.setVersion(abstractArchiveTask.getVersion());
				}

			});
	}

	private static final String _GROUP_ID =
		"com.liferay.poshi.runner.resources";

	private static final String _ROOT_DIR_NAME = "testFunctional";

}

==> com.liferay.gradle.plugins.defaults-7.0.308-sources-commercial.jar: com/liferay/gradle/plugins/defaults/PoshiRunnerResourcesDefaultsPlugin.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.gradle.plugins.defaults;

import com.liferay.gradle.plugins.defaults.internal.util.GitRepo;
import com.liferay.gradle.plugins.defaults.internal.util.GradlePluginsDefaultsUtil;
import com.liferay.gradle.plugins.defaults.internal.util.GradleUtil;
import com.liferay.gradle.plugins.poshi.runner.PoshiRunnerResourcesExtension;
import com.liferay.gradle.plugins.poshi.runner.PoshiRunnerResourcesPlugin;

import groovy.lang.Closure;

import java.io.File;

import org.gradle.api.Action;
import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.Task;
import org.gradle.api.artifacts.Configuration;
import org.gradle.api.artifacts.PublishArtifactSet;
import org.gradle.api.artifacts.dsl.RepositoryHandler;
import org.gradle.api.artifacts.maven.MavenDeployer;
import org.gradle.api.artifacts.maven.MavenPom;
import org.gradle.api.internal.artifacts.publish.ArchivePublishArtifact;
import org.gradle.api.plugins.MavenPlugin;
import org.gradle.api.plugins.MavenRepositoryHandlerConvention;
import org.gradle.api.specs.Spec;
import org.gradle.api.tasks.Upload;
import org.gradle.api.tasks.bundling.AbstractArchiveTask;

/**
 * @author Andrea Di Giorgi
 */
public class PoshiRunnerResourcesDefaultsPlugin implements Plugin<Project> {

	public static final String ARTIFACT_APPENDIX_PROPERTY_NAME =
		"artifactAppendix";

	public static final String ARTIFACT_VERSION_PROPERTY_NAME =
		"artifactVersion";

	@Override
	public void apply(Project project) {
		GradlePluginsDefaultsUtil.configureRepositories(project, null);

		GradleUtil.applyPlugin(project, MavenPlugin.class);
		GradleUtil.applyPlugin(project, PoshiRunnerResourcesPlugin.class);

		_applyConfigScripts(project);
		_configurePoshiRunnerResources(project);
		_configureTaskUploadPoshiRunnerResources(project);
	}

	private void _applyConfigScripts(Project project) {
		GradleUtil.applyScript(
			project,
			"com/liferay/gradle/plugins/defaults/dependencies" +
				"/config-maven.gradle",
			project);
	}

	private void _configurePoshiRunnerResources(Project project) {
		PoshiRunnerResourcesExtension poshiRunnerResourcesExtension =
			GradleUtil.getExtension(
				project, PoshiRunnerResourcesExtension.class);

		poshiRunnerResourcesExtension.setRootDirName(_ROOT_DIR_NAME);

		if (project.hasProperty(ARTIFACT_APPENDIX_PROPERTY_NAME)) {
			String artifactAppendix = GradleUtil.getProperty(
				project, ARTIFACT_APPENDIX_PROPERTY_NAME, (String)null);

			poshiRunnerResourcesExtension.setArtifactAppendix(artifactAppendix);
		}

		if (project.hasProperty(ARTIFACT_VERSION_PROPERTY_NAME)) {
			String artifactVersion = GradleUtil.getProperty(
				project, ARTIFACT_VERSION_PROPERTY_NAME, (String)null);

			poshiRunnerResourcesExtension.setArtifactVersion(artifactVersion);
		}
	}

	private void _configureTaskUploadPoshiRunnerResources(
		final Project project) {

		Upload upload = (Upload)GradleUtil.getTask(
			project,
			PoshiRunnerResourcesPlugin.UPLOAD_POSHI_RUNNER_RESOURCES_TASK_NAME);

		upload.onlyIf(
			new Spec<Task>() {

				@Override
				public boolean isSatisfiedBy(Task task) {
					GitRepo gitRepo = GitRepo.getGitRepo(
						project.getProjectDir());

					if ((gitRepo != null) && gitRepo.readOnly) {
						return false;
					}

					return true;
				}

			});

		RepositoryHandler repositoryHandler = upload.getRepositories();

		final MavenDeployer mavenDeployer =
			(MavenDeployer)repositoryHandler.getAt(
				MavenRepositoryHandlerConvention.DEFAULT_MAVEN_DEPLOYER_NAME);

		Configuration configuration = upload.getConfiguration();

		PublishArtifactSet publishArtifactSet = configuration.getAllArtifacts();

		publishArtifactSet.withType(
			ArchivePublishArtifact.class,
			new Action<ArchivePublishArtifact>() {

				@Override
				@SuppressWarnings("serial")
				public void execute(
					ArchivePublishArtifact archivePublishArtifact) {

					AbstractArchiveTask abstractArchiveTask =
						archivePublishArtifact.getArchiveTask();

					final String name = abstractArchiveTask.getArchiveName();

					mavenDeployer.addFilter(
						name,
						new Closure<Boolean>(project) {

							@SuppressWarnings("unused")
							public Boolean doCall(Object artifact, File file) {
								if (name.equals(file.getName())) {
									return true;
								}

								return false;
							}

						});

					MavenPom mavenPom = mavenDeployer.pom(name);

					mavenPom.setGroupId(_GROUP_ID);
					mavenPom.setVersion(abstractArchiveTask.getVersion());
				}

			});
	}

	private static final String _GROUP_ID =
		"com.liferay.poshi.runner.resources";

	private static final String _ROOT_DIR_NAME = "testFunctional";

}
